#==========================================================
# PgAckages --
#
#   procedures for making small-app installation easier
#
#==========================================================
#
namespace eval PgAckages {
    variable Win
    variable filename
    variable usage
}


#----------------------------------------------------------
#----------------------------------------------------------
#
proc ::PgAckages::init {{usage_ ""}} {

    variable usage

    set usage $usage_

    Window show .pgaw:PgAckages:file
    tkwait visibility .pgaw:PgAckages:file

}; # end proc ::PgAckages::init

#----------------------------------------------------------
#----------------------------------------------------------
#
proc ::PgAckages::save {} {

    variable filename

    set ilist [list]

    # first we introspect the PGA objects
    foreach item [::Database::getObjectsList Graphs] {
        lappend ilist [::Graphs::introspect $item]
    }
    foreach item [::Database::getObjectsList Forms] {
        lappend ilist [::Forms::introspect $item]
    }
    foreach item [::Database::getObjectsList Scripts] {
        lappend ilist [::Scripts::introspect $item]
    }
    foreach item [::Database::getObjectsList Queries] {
        lappend ilist [::Queries::introspect $item]
    }
    foreach item [::Database::getObjectsList Reports] {
        lappend ilist [::Reports::introspect $item]
    }
    foreach item [::Database::getObjectsList Diagrams] {
        lappend ilist [::Diagrams::introspect $item]
    }
    foreach item [::Database::getObjectsList Images] {
        lappend ilist [::Images::introspect $item]
    }
    # next we introspect the PG objects
    foreach item [::Database::getObjectsList Sequences] {
        lappend ilist [::Sequences::introspect $item]
    }
    foreach item [::Database::getObjectsList Tables] {
        # dont get pg_ or pga_ tables involved
        if {![string match "pg_*" $item] && ![string match "pga_*" $item]} {
            lappend ilist [::Tables::introspect $item]
        }
    }
    foreach item [::Database::getObjectsList Functions] {
        lappend ilist [::Functions::introspect $item]
    }
    foreach item [::Database::getObjectsList Views] {
        lappend ilist [::Views::introspect $item]
    }

    catch {
        set fid [open $filename w]
        puts $fid \
"
--
-- PgAccess PgAckage
--
"
        foreach i $ilist {
            puts $fid \
"-- PGA"
            puts $fid $i

        }
        puts $fid \
"-- PGA"
        close $fid
    }

}; # end proc ::PgAckages::save


#----------------------------------------------------------
#----------------------------------------------------------
#
proc ::PgAckages::load {} {

    global CurrentDB

    variable filename

    set retval [catch {set fid [open $filename r]} errmsg]
    if {! $retval} {
        set sql [read $fid [file size $filename]]
        close $fid
        set str "-- PGA"
        set sql [string trim [string range $sql [expr {[string first $str $sql]+[string length $str]}] end]]
        while {[string length $sql]>0} {
            set qry [string trim [string range $sql 0 [expr {[string first $str $sql]-1}]]]
            set sql [string trim [string range $sql [expr {[string first $str $sql]+[string length $str]}] end]]
            if {[string length $qry]>0} {
                sql_exec noquiet $qry
                # puts $qry
            }
        }
    }

    return $retval

}; # end proc ::PgAckages::load


#----------------------------------------------------------
#----------------------------------------------------------
#
proc ::PgAckages::createFileBox {} {

    variable Win
    variable usage

    set types {
        {{PgAckage Files} {.pga}}
        {{All Files} *}
    }

    if {$usage == "load"} {
        if {[catch {tk_getOpenFile \
                -parent $::PgAckages::Win(fdlg) \
                -filetypes $types \
                -title [intlmsg {Load PgAckage}]} \
                ::PgAckages::filename] || \
                [string match {} $::PgAckages::filename]} return
    } else {
        if {[catch {tk_getSaveFile \
                -parent $::PgAckages::Win(fdlg) \
                -filetypes $types \
                -title [intlmsg {Save PgAckage}]} \
                ::PgAckages::filename] || \
                [string match {} $::PgAckages::filename]} return
    }

}; # end proc ::PgAckages::createFileBox



########## END NAMESPACE PgAckages



proc vTclWindow.pgaw:PgAckages:file {base} {

    variable ::PgAckages::Win

    if {$base == "" } {
        set base .pgaw:PgAckages:file
    }

    set Win(fdlg) $base

    if {[winfo exists $base]} {
        wm deiconify $base
        return
    }

    toplevel $base -class Toplevel
    wm focusmodel $base passive
    wm geometry $base 400x100+520+559
    wm maxsize $base 1265 994
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm title $base [intlmsg {PgAckages}]

    frame $base.ffile \
        -borderwidth 2 \
        -height 50 \
        -width 400
    LabelEntry $base.ffile.lefilename \
        -label [intlmsg {PgAckage File}] \
        -textvariable ::PgAckages::filename
    Button $base.ffile.bbrowse \
        -text [intlmsg {Browse}] \
        -command {
            ::PgAckages::createFileBox
        }

    frame $base.fbtn \
        -borderwidth 2 \
        -height 50 \
        -width 400
    if {$::PgAckages::usage == "save"} {
        Button $base.fbtn.busage \
            -image ::icon::filesave-22 \
            -helptext [intlmsg {Save}] \
            -command [subst {
                ::PgAckages::save
                destroy $Win(fdlg)
            }]
    } else {
        Button $base.fbtn.busage \
            -image ::icon::fileopen-22 \
            -helptext [intlmsg {Load}] \
            -command [subst {
                ::PgAckages::load
                destroy $Win(fdlg)
            }]
    }

    Button $base.fbtn.bclose \
        -image ::icon::exit-22 \
        -helptext [intlmsg {Close}] \
        -command [subst {
            destroy $Win(fdlg)
        }]


    pack $base.ffile \
        -in $base \
        -anchor center \
        -expand 1 \
        -fill x \
        -side top
    pack $base.ffile.lefilename \
        -in $base.ffile \
        -anchor center \
        -expand 1 \
        -fill x \
        -side left
    pack $base.ffile.bbrowse \
        -in $base.ffile \
        -anchor center \
        -expand 1 \
        -fill x \
        -side left

    pack $base.fbtn \
        -in $base \
        -anchor center \
        -expand 1 \
        -fill both \
        -side top
    pack $base.fbtn.busage \
        -in $base.fbtn \
        -anchor center \
        -expand 1 \
        -fill both \
        -side left
    pack $base.fbtn.bclose \
        -in $base.fbtn \
        -anchor center \
        -expand 1 \
        -fill both \
        -side left


}
